@@ -63,7 +63,7 @@
 #define IGNORE_BLANKS		"/ignore-blanks"
 
 #define MENU_ITEM_LABEL		N_("Co_mpare Files...")
-#define MENU_ITEM_PATH		"/menu/File/FileOps_2/"
+#define MENU_ITEM_PATH		"/menu/Tools/ToolsOps_3/"
 #define MENU_ITEM_NAME		"Diff"	
 #define MENU_ITEM_TIP		N_("Makes a diff file from two documents or files")
 
@@ -268,7 +268,7 @@ get_diff_dialog (GtkWindow* parent)
 	dialog = g_new0 (DiffDialog, 1);
 
 	/* Create the dialog */
-	dialog->dialog = gtk_dialog_new_with_buttons (_("Compare two files..."),
+	dialog->dialog = gtk_dialog_new_with_buttons (_("Compare Files"),
 						      parent,
 						      GTK_DIALOG_DESTROY_WITH_PARENT |
 						      GTK_DIALOG_MODAL,
