@@ -493,7 +493,7 @@ gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 	model = gedit_recent_get_model ();
 	view = EGG_RECENT_VIEW (egg_recent_view_bonobo_new (
 					ui_component, "/menu/File/Recents"));
-	egg_recent_view_bonobo_show_icons (EGG_RECENT_VIEW_BONOBO (view), TRUE);
+	egg_recent_view_bonobo_show_icons (EGG_RECENT_VIEW_BONOBO (view), FALSE);
 	egg_recent_view_set_model (view, model);
 	
 	g_signal_connect (G_OBJECT (view), "activate",
@@ -1262,7 +1262,7 @@ gedit_mdi_set_active_window_verbs_sensitivity (BonoboMDI *mdi)
 	bonobo_ui_component_freeze (ui_component, NULL);
 	
 	gedit_plugins_engine_update_plugins_ui (active_window, FALSE);
-
+	
 	if (active_child == NULL)
 	{
 		gedit_menus_set_verb_list_sensitive (ui_component, 
@@ -1275,6 +1275,9 @@ gedit_mdi_set_active_window_verbs_sensitivity (BonoboMDI *mdi)
 				gedit_menus_all_sensible_verbs, TRUE);
 	}
 
+	gedit_menus_set_verb_sensitive (ui_component, "/commands/DocumentsMoveToNewWindow",
+				(bonobo_mdi_n_children_for_window (active_window) > 1) ? TRUE : FALSE);
+
 	doc = GEDIT_MDI_CHILD (active_child)->document;
 	g_return_if_fail (doc != NULL);
 	
