@@ -34,9 +34,9 @@
 
 #include <libgnome/libgnome.h>
 #include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-print-master.h>
+#include <libgnomeprint/gnome-print-job.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
-#include <libgnomeprintui/gnome-print-master-preview.h>
+#include <libgnomeprintui/gnome-print-job-preview.h>
 #include <eel/eel-string.h>
 
 #include <string.h>	/* For strlen */
@@ -65,7 +65,7 @@ struct _GeditPrintJobInfo {
 	GnomePrintConfig 	*config;
 	gint			 range_type;
 
-	GnomePrintMaster	*print_master;
+	GnomePrintJob		*print_job;
 	GnomePrintContext	*print_ctx;
 
 	gint			 page_num;
@@ -94,9 +94,6 @@ struct _GeditPrintJobInfo {
 };
 
 
-/* FIXME: remove when libgnomeprint well define it -- Paolo */
-GnomeGlyphList *gnome_glyphlist_unref (GnomeGlyphList *gl);
-
 static GQuark gedit_print_error_quark (void);
 #define GEDIT_PRINT_ERROR gedit_print_error_quark ()	
 
@@ -230,8 +227,8 @@ gedit_print_job_info_destroy (GeditPrintJobInfo *pji)
 	if (pji->print_ctx != NULL)
 		g_object_unref (pji->print_ctx);
 
-	if (pji->print_master != NULL)
-		g_object_unref (pji->print_master);
+	if (pji->print_job != NULL)
+		g_object_unref (pji->print_job);
 
 	g_free (pji);
 }
@@ -243,7 +240,7 @@ gedit_print_update_page_size_and_margins (GeditPrintJobInfo *pji)
 		
 	gedit_debug (DEBUG_PRINT, "");
 
-	gnome_print_master_get_page_size_from_config (pji->config, 
+	gnome_print_job_get_page_size_from_config (pji->config, 
 			&pji->page_width, &pji->page_height);
 
 	if (gnome_print_config_get_length (pji->config, GNOME_PRINT_KEY_PAGE_MARGIN_LEFT, 
@@ -298,7 +295,7 @@ gedit_print_run_dialog (GeditPrintJobInfo *pji)
 
 	g_return_val_if_fail (pji != NULL, TRUE);
 	
-	if (!gedit_document_has_selected_text (pji->doc))
+	if (!gedit_document_get_selection (pji->doc, NULL, NULL))
 		selection_flag = GNOME_PRINT_RANGE_SELECTION_UNSENSITIVE;
 	else
 		selection_flag = GNOME_PRINT_RANGE_SELECTION;
@@ -416,22 +413,30 @@ gedit_print_document (GeditPrintJobInfo *pji)
 	gint paragraph_delimiter_index;
 	gint next_paragraph_start;
 	gdouble fontheight;
-	gint start;
+	gint start, end_sel;
 	
 	gedit_debug (DEBUG_PRINT, "");	
 	
 	switch (pji->range_type)
 	{
 		case GNOME_PRINT_RANGE_ALL:
-			text_to_print = gedit_document_get_buffer (pji->doc);
+			text_to_print = gedit_document_get_chars (pji->doc, 0, -1);
 			text_end = text_to_print + strlen (text_to_print);
 			break;
 		case GNOME_PRINT_RANGE_SELECTION:
-			text_to_print = gedit_document_get_selected_text (pji->doc, &start, NULL);
-			text_end = text_to_print + strlen (text_to_print);
+			if (gedit_document_get_selection (pji->doc, &start, &end_sel))
+			{
+				text_to_print = gedit_document_get_chars (pji->doc, 
+							start, end_sel);
+				
+				text_end = text_to_print + strlen (text_to_print);
+		
+				pji->first_line_to_print =  
+					gedit_document_get_line_at_offset (pji->doc, start) + 1;
+			}
+			else
+				g_return_if_fail (FALSE);
 
-			pji->first_line_to_print =  
-				gedit_document_get_line_at_offset (pji->doc, start) + 1;
 			break;
 		default:
 			g_return_if_fail (FALSE);
@@ -512,10 +517,10 @@ gedit_print_preview_real (GeditPrintJobInfo *pji)
 	gedit_debug (DEBUG_PRINT, "");
 
 	g_return_if_fail (pji != NULL);
-	g_return_if_fail (pji->print_master != NULL);
+	g_return_if_fail (pji->print_job != NULL);
 
 	title = g_strdup_printf (_("gedit - Print Preview"));
-	gpmp = gnome_print_master_preview_new (pji->print_master, title);
+	gpmp = gnome_print_job_preview_new (pji->print_job, title);
 	g_free (title);
 
 	gtk_widget_show (gpmp);
@@ -557,10 +562,10 @@ gedit_print_real (GeditDocument* doc, gboolean preview, GError **error)
 
 	g_return_if_fail (pji->config != NULL);
 
-	pji->print_master = gnome_print_master_new_from_config (pji->config);
-	g_return_if_fail (pji->print_master != NULL);
+	pji->print_job = gnome_print_job_new (pji->config);
+	g_return_if_fail (pji->print_job != NULL);
 
-	pji->print_ctx = gnome_print_master_get_context (pji->print_master);
+	pji->print_ctx = gnome_print_job_get_context (pji->print_job);
 	g_return_if_fail (pji->print_ctx != NULL);
 
 	gedit_print_update_page_size_and_margins (pji);
@@ -572,12 +577,12 @@ gedit_print_real (GeditDocument* doc, gboolean preview, GError **error)
 		return;
 	}
 #endif	
-	gnome_print_master_close (pji->print_master);
+	gnome_print_job_close (pji->print_job);
 
 	if (pji->preview)
 		gedit_print_preview_real (pji);
 	else
-		gnome_print_master_print (pji->print_master);
+		gnome_print_job_print (pji->print_job);
 	
 	gedit_print_job_info_destroy (pji);
 }
@@ -586,17 +591,15 @@ static void
 gedit_print_error_dialog (GError *error)
 {
 	GtkWidget *dialog;
-	gchar *errstr;
-		       	
-	errstr = g_strdup_printf (_("An error occurred while printing.\n\n%s,"), error->message);
-		
+
 	dialog = gtk_message_dialog_new (
 			GTK_WINDOW (bonobo_mdi_get_active_window (BONOBO_MDI (gedit_mdi))),
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		   	GTK_MESSAGE_ERROR,
 		   	GTK_BUTTONS_OK,
-			errstr);
-			
+			_("An error occurred while printing.\n\n%s,"),
+			error->message);
+
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -604,8 +607,6 @@ gedit_print_error_dialog (GError *error)
 	gtk_dialog_run (GTK_DIALOG (dialog));
 
 	gtk_widget_destroy (dialog);
-			
-	g_free (errstr);
 }
 
 
@@ -658,6 +659,7 @@ gedit_print_get_next_line_to_print_delimiter (GeditPrintJobInfo *pji,
 		const gchar *start, const gchar *end, gboolean first_line_of_par)
 {
 	const gchar* p;
+	const gchar* t;
 	gdouble line_width = 0.0;
 	gdouble printable_page_width;
 	ArtPoint space_advance;
@@ -674,6 +676,7 @@ gedit_print_get_next_line_to_print_delimiter (GeditPrintJobInfo *pji,
 			(pji->margin_right + pji->margin_left);
 	
 	p = start;
+	t = start;
 
 	/* Find space advance */
 	space = gnome_font_lookup_default (pji->font_body, ' ');
@@ -707,14 +710,17 @@ gedit_print_get_next_line_to_print_delimiter (GeditPrintJobInfo *pji,
 			chars_in_this_line += num_of_equivalent_spaces - 1;
 			
 			line_width += (num_of_equivalent_spaces * space_advance.x); 
+			t = p;
 		}
 		else
 		{
 			glyph = gnome_font_lookup_default (pji->font_body, ch);
 
 			/* FIXME */
-			if (glyph == space)
+			if (glyph == space){			
 				line_width += space_advance.x;
+				t = p;
+			}
 			else
 			/*
 			if ((glyph < 0) || (glyph >= 256))
@@ -738,8 +744,15 @@ gedit_print_get_next_line_to_print_delimiter (GeditPrintJobInfo *pji,
 
 		if (line_width > printable_page_width)
 		{
-			/* FIXME: take care of lines wrapping at word boundaries too */
-			return p;
+                        /* Fix for word wrap at line boundaries */
+                        if (pji->print_wrap_mode == GTK_WRAP_WORD)
+			{
+                                if (t == start)   /* handling words longer than a line */
+                                        return p;
+                                return t;	 
+                        }
+
+                        return p; /* keeping char-wrap and wrap-none unaltered */
 		}
 
 		p = g_utf8_next_char (p);
